## 适用范围：

**该包适用于《数据结构教程（python语言描述）》清华大学出版社**

## 引用方式：

**可参照该书目录，ch2，ch3，....ch9分别对应于2-9章的数据结构**

例如：
```python
from data_structure.data_structure import CDLinkList
a = CDLinkList()
a.CreateListF([1,2,3])
a.display()
```
源代码可在我个人GitHub上查看https://github.com/renyumeng1/sound-code

